@@ -1,7 +1,10 @@
 #[cfg(feature = "sled-storage")]
 mod sled_multi_threaded {
     use {
-        gluesql::prelude::{Glue, Payload, SledStorage, Value},
+        gluesql::{
+            prelude::{Glue, Payload, Value},
+            sled_storage::SledStorage,
+        },
         std::thread,
     };
 
@@ -62,10 +65,7 @@ mod sled_multi_threaded {
     }
 }
 
-#[cfg(feature = "sled-storage")]
 fn main() {
+    #[cfg(feature = "sled-storage")]
     sled_multi_threaded::run();
 }
-
-#[cfg(not(feature = "sled-storage"))]
-fn main() {}
